<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => '初めてSPIPの管理エリアをご訪問する時、仲間さんは、援助を提供してくださいます。',
	'compagnon_nom' => '仲間さん',
	'compagnon_slogan' => 'SPIPを使用するように、最初のステップウィザードです。',
];
